pub struct LPWeb24a {
pub prvs: Vec<(String, Vec<LPWeb24aX>)>,
}Fields
prvs: Vec<(String, Vec<LPWeb24aX>)>Trait Implementations
Sourceimpl IntoResponse for LPWeb24a
impl IntoResponse for LPWeb24a
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for LPWeb24a
impl Template for LPWeb24a
Sourceconst SIZE_HINT: usize = 1061
const SIZE_HINT: usize = 1061
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for LPWeb24a
impl RefUnwindSafe for LPWeb24a
impl Send for LPWeb24a
impl Sync for LPWeb24a
impl Unpin for LPWeb24a
impl UnsafeUnpin for LPWeb24a
impl UnwindSafe for LPWeb24a